# Instructions for the Benchmark

This section covers instructions for specific aspects of the Space Robotics Bench.

- [Simulating Parallel Environments](./parallel_envs.md)
- [Random and Zero Agents](./random_zero_agents.md)
- [Enabling Visual Observations](./visual_observations.md)
- [Graphical User Interface](./gui.md)
- [Benchmark Configuration](./cfg.md)
